@@ -19,13 +19,13 @@ class DataInstance(S3Client):
         filePath = LOCAL_BUCKET_PATH + path
         if(os.path.isfile(filePath)):
             print("Reading data from cache")
-            pd.read_csv(filePath)
+            return pd.read_csv(filePath)
         else:
             try:
                 self.download(path,filePath)
-                pd.read_csv(filePath)
+                return pd.read_csv(filePath)
             except exceptions.ClientError as e:
                 if e.response['Error']['Code'] == "404":
                     print(f"File not found in remote bucket {self.bucket_name}")
                 else:
-                    raise
+                    raise e
